summaryrefslogtreecommitdiffstats
path: root/lib/public/template.php
diff options
context:
space:
mode:
Diffstat (limited to 'lib/public/template.php')
-rw-r--r--lib/public/template.php5
1 files changed, 3 insertions, 2 deletions
diff --git a/lib/public/template.php b/lib/public/template.php
index 69997ad42b6..3b1a4ed4906 100644
--- a/lib/public/template.php
+++ b/lib/public/template.php
@@ -96,12 +96,13 @@ function relative_modified_date($timestamp) {
/**
* @brief Return a human readable outout for a file size.
* @param $byte size of a file in byte
* @returns human readable interpretation of a file size
*/
function simple_file_size($bytes) {
- return(\simple_file_size($bytes));
+ return(\human_file_size($bytes));
}
@@ -96,12 +96,13 @@ function relative_modified_date($timestamp) {
/**
- * @brief Return a human readable outout for a file size.
+ * @brief DEPRECATED Return a human readable outout for a file size.
+ * @deprecated human_file_size() instead
* @param $byte size of a file in byte
* @returns human readable interpretation of a file size